==> haskell-sorted-list-0.2.3.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sorted-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sorted-list
version:              0.2.3.1
visibility:           public
id:                   sorted-list-0.2.3.1-2GnDP4ox5wFD9YsDb9X4XY
key:                  sorted-list-0.2.3.1-2GnDP4ox5wFD9YsDb9X4XY
license:              MIT
maintainer:           Daniel Casanueva (coding `at` danielcasanueva.eu)
author:               Daniel Casanueva (coding `at` danielcasanueva.eu)
synopsis:             Type-enforced sorted lists and related functions.
description:
    Type-enforced sorted lists and related functions.

    These are useful for:

    * Constraining the argument of a function to be a sorted list
    by stating in your type that the input list is a sorted list.

    * Avoiding sorting a list twice.

    * Creating a list that is sorted from the moment of its construction,
    so it doesn'\''t have to be sorted later.

    * Performing list operations keeping the input list sorted.

    * Improving those list operations that can be
    benefited from the ordering of its elements.

    * Creating infinite lists that are sorted!

    * And more!

    If you are missing a feature, do not hesitate
    to ask by opening an issue at the bug-tracker.

category:             Data
abi:                  63b753da252e5736e7b35c03d1713284
exposed:              True
exposed-modules:      Data.SortedList
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sorted-list
hs-libraries:         HSsorted-list-0.2.3.1-2GnDP4ox5wFD9YsDb9X4XY
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-sorted-list/html/sorted-list.haddock
haddock-html:         /usr/share/doc/haskell-sorted-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sorted-list-0.2.3.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sorted-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sorted-list
version:              0.2.3.1
visibility:           public
id:                   sorted-list-0.2.3.1-5dI0c0wGWqGLJypOL2Ea2d
key:                  sorted-list-0.2.3.1-5dI0c0wGWqGLJypOL2Ea2d
license:              MIT
maintainer:           Daniel Casanueva (coding `at` danielcasanueva.eu)
author:               Daniel Casanueva (coding `at` danielcasanueva.eu)
synopsis:             Type-enforced sorted lists and related functions.
description:
    Type-enforced sorted lists and related functions.

    These are useful for:

    * Constraining the argument of a function to be a sorted list
    by stating in your type that the input list is a sorted list.

    * Avoiding sorting a list twice.

    * Creating a list that is sorted from the moment of its construction,
    so it doesn'\''t have to be sorted later.

    * Performing list operations keeping the input list sorted.

    * Improving those list operations that can be
    benefited from the ordering of its elements.

    * Creating infinite lists that are sorted!

    * And more!

    If you are missing a feature, do not hesitate
    to ask by opening an issue at the bug-tracker.

category:             Data
abi:                  f4d091a239403d3c2b1a6fe82fda6b26
exposed:              True
exposed-modules:      Data.SortedList
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sorted-list
hs-libraries:         HSsorted-list-0.2.3.1-5dI0c0wGWqGLJypOL2Ea2d
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-sorted-list/html/sorted-list.haddock
haddock-html:         /usr/share/doc/haskell-sorted-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
